package com.supermap.samplecode.data;

/**
 * <p>
 * Title:投影转换
 * </p>
 * 
 * <p>
 * Description:
 * ============================================================================>
 * ------------------------------版权声明----------------------------
 * 此文件为SuperMap Objects Java 的示范代码 
 * 版权所有：北京超图软件股份有限公司
 * ----------------------------------------------------------------
 * ---------------------SuperMap iObjects Java 示范程序说明------------------------
 * 
 * 1、范例简介：展示投影转换；
 * 2、示例数据：安装目录\SampleData\China\China400.smwu;
 * 3、关键类型/成员: 
 *      CoordSysTranslator.convert 方法
 *      
 * 4、使用步骤：
 *  (1)点击高斯-克吕格投影转换按钮，显示投影转换结果。
 *	(2)点击UTM投影转换按钮，显示投影转换结果。
 * 	(3)点击兰勃托投影转换按钮，显示投影转换结果。
 * ------------------------------------------------------------------------------
 * ============================================================================>
 * </p> 
 * 
 * <p>
 * Company: 北京超图软件股份有限公司
 * </p>
 * 
 */

/**
 * <p>
 * Title:PrjCoordSysTransform
 * </p>
 * 
 * <p>
 * Description:
 * ============================================================================>
 * ------------------------------CopyRight----------------------------
 *This file contents the sample code of SuperMap Objects Java.
 * Copyright @2005-2012 SuperMap Software Co., Ltd. All Rights Reserved. 
 * ----------------------------------------------------------------
 * ---------------------SuperMap Objects Java Sample Code Description------------------------
 * 
 * 1.   Sample Code Description:  The following code demonstrates how to display the projection transform.
 * 2.  Sample Data:Installation directory\SampleData\China\China400.smwu;
 * 3.  Key Classes/Methods:
 *      CoordSysTranslator.convert 
 *      
 * 4.  Procedures
 *(1)Click "GKTransform" button, to display the result.
 *(2)Click "UTM Transform" button ,to display the result. 
 * (3)Click "Lambert Transform" button, to display the result.
 * ------------------------------------------------------------------------------
 * ============================================================================>
 * </p> 
 * 
 * <p>
 * Company:SuperMap Software Co., Ltd
 * </p>
 * 
 */

import java.awt.BorderLayout;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JSplitPane;
import javax.swing.JTextArea;
import javax.swing.JToolBar;
import javax.swing.SwingUtilities;

import com.supermap.data.Workspace;
import com.supermap.ui.MapControl;

public class MainFrame extends JFrame {

	private static final long serialVersionUID = 1L;

	private Workspace m_workspace = null;
	
	private MapControl m_mapControlSrc = null;
	
	private MapControl m_mapControlDes = null;
	
	private JTextArea m_textAreaSrc = null;

	private JTextArea m_textAreaDes = null;

	private JPanel m_contentPane = null;

	private JToolBar m_toolBarPrjsysTransform = null;

	private JButton m_buttonGKTransform = null;

	private JButton m_buttonUTMTransform = null;

	private JButton m_buttonLambertTransform = null;

	private SampleRun m_sampleRun = null;
	
	private JSplitPane m_splitPaneVertical = null;

	private JSplitPane m_splitPaneHorizonLeft = null;

	private JSplitPane m_splitPaneHorizonRight = null;
	
	private JScrollPane m_scrollPaneSrc = null;
	
	private JScrollPane m_scrollPaneDes = null;


	/**
	 * 初始化m_scrollPaneSrc
	 * Initialize m_scrollPaneSrc
	 */
	/**
	 * This method initializes m_scrollPaneSrc	
	 * 	
	 * @return javax.swing.JScrollPane	
	 */
	private JScrollPane getScrollPaneSrc() {
		if (m_scrollPaneSrc == null) {
			m_scrollPaneSrc = new JScrollPane();
			m_scrollPaneSrc.setViewportView(getTextPaneSrc());
		}
		return m_scrollPaneSrc;
	}
	
	/**
	 * 初始化m_scrollPaneDes
	 * Initialize m_scrollPaneDes
	 */
	private JScrollPane getScrollPaneDes() {
		if (m_scrollPaneDes == null) {
			m_scrollPaneDes = new JScrollPane();
			m_scrollPaneDes.setViewportView(getTextPaneDes());
		}
		return m_scrollPaneDes;
	}
	
	
	
	
	/**
	 * 初始化m_splitPaneVertical
	 * Initialize m_splitPaneVertical
	 */
	private JSplitPane getSplitPaneVertical() {
		if (m_splitPaneVertical == null) {
			m_splitPaneVertical = new JSplitPane();
			m_splitPaneVertical.setOrientation(JSplitPane.HORIZONTAL_SPLIT);
			m_splitPaneVertical.setTopComponent(getSplitPaneHorizonLeft());
			m_splitPaneVertical.setBottomComponent(getSplitPaneHorizonRight());
		}
		return m_splitPaneVertical;
	}

	
	/**
	 * 初始化m_splitPaneHorizonFst
	  * Initialize m_splitPaneHorizonFst
	 */
	private JSplitPane getSplitPaneHorizonLeft() {
		if (m_splitPaneHorizonLeft == null) {
			m_splitPaneHorizonLeft = new JSplitPane();
			m_splitPaneHorizonLeft.setOrientation(JSplitPane.VERTICAL_SPLIT);
			m_splitPaneHorizonLeft.setTopComponent(getMapControlSrc());
			m_splitPaneHorizonLeft.setBottomComponent(getScrollPaneSrc());
		}
		return m_splitPaneHorizonLeft;
	}

	/**
	 * 初始化m_splitPaneHorizonSnd
	 * Initialize m_splitPaneHorizonSnd
	 */
	private JSplitPane getSplitPaneHorizonRight() {
		if (m_splitPaneHorizonRight == null) {
			m_splitPaneHorizonRight = new JSplitPane();
			m_splitPaneHorizonRight.setOrientation(JSplitPane.VERTICAL_SPLIT);
			m_splitPaneHorizonRight.setTopComponent(getMapControlDes());
			m_splitPaneHorizonRight.setBottomComponent(getScrollPaneDes());
		}
		return m_splitPaneHorizonRight;
	}

	/**
	 * 初始化m_textAreaSrc
	 * Initialize m_textAreaSrc
	 */
	private JTextArea getTextPaneSrc() {
		if (m_textAreaSrc == null) {
			m_textAreaSrc = new JTextArea();
			m_textAreaSrc.setEditable(false);
		}
		return m_textAreaSrc;
	}

	/**
	 * 初始化m_textPaneResource
	 * Initialize m_textPaneResource
	 */
	private JTextArea getTextPaneDes() {
		if (m_textAreaDes == null) {
			m_textAreaDes = new JTextArea();
			m_textAreaDes.setEditable(false);
		}
		return m_textAreaDes;
	}

	
	/**
	 * 程序入口
	 * The main entrance
	 */
	public static void main(String[] args) {
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				MainFrame thisClass = new MainFrame();
				thisClass.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
				thisClass.setVisible(true);
				thisClass.updateSplitPane();
			}
		});
	}
	
	/**
	 * 构造函数
	 * This is the default constructor
	 */
	public MainFrame() {
		super();
		initialize();
	}

	/**
	 * 初始化MainFrame对象
	 * Initialize MainFrame
	 */
	private void initialize() {
		// 最大化显示窗体
		// Maximum display the form.
		this.setSize(1198, 629);
		this.setExtendedState(Frame.MAXIMIZED_BOTH);
		this.setContentPane(getJContentPane());
		updateSplitPane();
		this.setTitle(getText("m_title"));
		
		
		this.addWindowListener(new java.awt.event.WindowAdapter() {
			// 在主窗体加载时，初始化SampleRun类型，来完成功能的展现
			// Initialize a SampleRun object when loading the main forms.
			public void windowOpened(java.awt.event.WindowEvent e) {
				m_workspace = new Workspace();
				m_sampleRun = new SampleRun(m_workspace, m_mapControlSrc,m_mapControlDes,m_textAreaSrc,m_textAreaDes);
			}

			// 在窗体关闭时，需要释放相关的资源
			//Dispose the resources when closing the forms.
			public void windowClosing(java.awt.event.WindowEvent e) {
				m_mapControlSrc.dispose();
				m_workspace.dispose();
			}
		});
	}
	
	/**
	 * 设置分割栏位置
	 * This method set Location of SplitpaneTransform
	 */
	public void updateSplitPane(){
		getSplitPaneVertical().setDividerLocation(0.5);
		getSplitPaneVertical().setResizeWeight(0.5);
		getSplitPaneHorizonLeft().setDividerLocation(0.99);
		getSplitPaneHorizonLeft().setResizeWeight(0.5); 
		getSplitPaneHorizonRight().setDividerLocation(0.99);
		getSplitPaneHorizonRight().setResizeWeight(0.5);
	}

	/**
	 * 获取m_contentPane
	 * Get m_contentPane
	 */
	private JPanel getJContentPane() {
		if (m_contentPane == null) {
			m_contentPane = new JPanel();
			m_contentPane.setLayout(new BorderLayout());
			m_contentPane.add(getToolBarPrjsysTransform(), BorderLayout.NORTH);
			m_contentPane.add(getSplitPaneVertical(), BorderLayout.CENTER);
		}
		return m_contentPane;
	}

	/**
	 * 构建工具栏 
	 * Too bar 
	 */
	private JToolBar getToolBarPrjsysTransform() {
		if (m_toolBarPrjsysTransform == null) {
			m_toolBarPrjsysTransform = new JToolBar();
			m_toolBarPrjsysTransform.add(getButtonGKTransform());
			m_toolBarPrjsysTransform.add(getButtonUTMTransform());
			m_toolBarPrjsysTransform.add(getButtonLambert());
			m_toolBarPrjsysTransform.setFloatable(false);
		}
		return m_toolBarPrjsysTransform;
	}

	/**
	 * 构建高斯-克吕格投影转换按钮 
	 * This method initializes m_buttonGKTransform
	 */
	private JButton getButtonGKTransform() {
		if (m_buttonGKTransform == null) {
			m_buttonGKTransform = new JButton();
			m_buttonGKTransform.setText(getText("m_buttonGKTransform"));
			m_buttonGKTransform.addActionListener(new ActionListener(){
				public void actionPerformed(ActionEvent e) {
					m_sampleRun.transform(1);
				}
			});
		}
		return m_buttonGKTransform;
	}

	/**
	 * 构建UTM投影转换按钮 
	 * This method initializes m_buttonUTMTransform 
	 */
	private JButton getButtonUTMTransform() {
		if (m_buttonUTMTransform == null) {
			m_buttonUTMTransform = new JButton();
			m_buttonUTMTransform.setText(getText("m_buttonUTMTransform"));
			m_buttonUTMTransform.addActionListener(new ActionListener(){
				public void actionPerformed(ActionEvent e) {
					m_sampleRun.transform(2);
				}
			});
		}
		return m_buttonUTMTransform;
	}
	
	/**
	 * 构建兰勃托投影转换按钮 
	 * This method initializes m_buttonLambert	 
	 */
	private JButton getButtonLambert() {
		if (m_buttonLambertTransform == null) {
			m_buttonLambertTransform = new JButton();
			m_buttonLambertTransform.setText(getText("m_buttonLambertTransform"));
			m_buttonLambertTransform.addActionListener(new ActionListener(){
				public void actionPerformed(ActionEvent e) {
					m_sampleRun.transform(3);
				}
			});
		}
		return m_buttonLambertTransform;
	}

	/**
	 * 构建MapControl控件 
	 * Initialize MapControl. 
	 */
	private MapControl getMapControlSrc() {
		if (m_mapControlSrc == null) {
			m_mapControlSrc = new MapControl();	
		}
		return m_mapControlSrc;
	}
	
	/**
	 * 构建MapControl控件 
	 * Initialize MapControl. 
	 */
	private MapControl getMapControlDes() {
		if (m_mapControlDes == null) {
			m_mapControlDes = new MapControl();	
		}
		return m_mapControlDes;
	}
	
	// 根据语言设置text是中文还是英文
	// To change text to English or Chinede by CurrentCulture
	private String getText(String id)
	{
		String text = "";
		if(com.supermap.data.Environment.getCurrentCulture().contentEquals("zh-CN"))
		{
			if(id == "m_title")
			{
				text = "投影转换";
			} 
			if(id == "m_buttonGKTransform")
			{
				text = "高斯-克吕格投影转换";
			}
			if(id == "m_buttonUTMTransform")
			{
				text = "UTM投影转换";
			}
			if(id == "m_buttonLambertTransform")
			{
				text = "兰勃托投影转换";
			}
		}
		else
		{
			if(id == "m_title")
			{
				text = "Projection Transform";
			} 
			if(id == "m_buttonGKTransform")
			{
				text = "GKTransform";
			}
			if(id == "m_buttonUTMTransform")
			{
				text = "UTM Transform";
			}
			if(id == "m_buttonLambertTransform")
			{
				text = "Lambert Transform";
			}
		}
		return text;
	}

}  //  @jve:decl-index=0:visual-constraint="10,10"

